OGBEvaluator
============

.. currentmodule:: pykeen.evaluation

.. autoclass:: OGBEvaluator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~OGBEvaluator.evaluate

   .. rubric:: Methods Documentation

   .. automethod:: evaluate
